Text = 'text'
Audio = 'audio'
Document = 'document'
Animation = 'animation'
Game = 'game'
Photo = 'photo'
Sticker = 'sticker'
Video = 'video'
Voice = 'voice'
VideoNote = 'video_note'
Contact = 'contact'
Location = 'location'
Venue = 'venue'
Poll = 'poll'
NewChatMembers = 'new_chat_members'
LeftChatMember = 'left_chat_member'
NewChatTitle = 'new_chat_title'
NewChatPhoto = 'new_chat_photo'
DeleteChatPhoto = 'delete_chat_photo'
GroupChatCreated = 'group_chat_created'
SupergroupChatCreated = 'supergroup_chat_created'
ChannelChatCreated = 'channel_chat_created'
MigrateToChatId = 'migrate_to_chat_id'
MigrateFromChatId = 'migrate_from_chat_id'
PinnedMessage = 'pinned_message'
Invoice = 'invoice'
SuccessfulPayment = 'successful_payment'
PassportData = 'passport_data'
